.. _references:

##########
References
##########

The main papers describing the algorithms found in `ttcrpy` are:

- Nasr, Maher; Giroux, Bernard et Dupuis, Christian J. (2020). A hybrid approach
  to compute seismic travel times in 3D tetrahedral meshes. Geophys. Prospect.
  DOI : 10.1111/1365-2478.12930
  https://onlinelibrary.wiley.com/doi/abs/10.1111/1365-2478.12930

- Giroux B et Larouche B. 2013. Task-parallel implementation of 3D shortest
  path raytracing for geophysical applications, Computers & Geosciences, 54,
  130-141. DOI :
  https://www.sciencedirect.com/science/article/pii/S0098300412004128

- Nasr M, Giroux B, Dupuis JC, 2018.  An optimized approach to compute
  traveltimes in 3D unstructured meshes.  SEG Technical Program Expanded
  Abstracts 2018, pp. 5073-5077. DOI : 10.1190/segam2018-2997918.1
  https://library.seg.org/doi/10.1190/segam2018-2997918.1

- Giroux B. 2014. Comparison of grid-based methods for raytracing on
  unstructured meshes, SEG Technical Program Expanded Abstracts 2014,
  pp. 3388-3392. DOI :
  https://library.seg.org/doi/10.1190/segam2014-1197.1

- Giroux B, 2013. Shortest path raytracing in tetrahedral meshes. 75th EAGE
  Conference & Exhibition, Londres, 10-13 June. DOI : 10.3997/2214-4609.20130236
  https://www.earthdoc.org/content/papers/10.3997/2214-4609.20130236
  
